Index: src/org/openstreetmap/josm/gui/dialogs/ConflictResolutionDialog.java
===================================================================
--- src/org/openstreetmap/josm/gui/dialogs/ConflictResolutionDialog.java	(Revision 2913)
+++ src/org/openstreetmap/josm/gui/dialogs/ConflictResolutionDialog.java	(Arbeitskopie)
@@ -216,7 +216,7 @@
                         tr("<html>You did not finish to merge the differences in this conflict.<br>"
                                 + "Conflict resolutions will not be applied unless all differences<br>"
                                 + "are resolved.<br>"
-                                + "Click <strong>{0}</strong> to close anyway.<strong>Already<br>"
+                                + "Click <strong>{0}</strong> to close anyway. <strong>Already<br>"
                                 + "resolved differences will not be applied.</strong><br>"
                                 + "Click <strong>{1}</strong> to return to resolving conflicts.</html>"
                                 , options[0].toString(), options[1].toString()
Index: src/org/openstreetmap/josm/gui/dialogs/changeset/SingleChangesetDownloadPanel.java
===================================================================
--- src/org/openstreetmap/josm/gui/dialogs/changeset/SingleChangesetDownloadPanel.java	(Revision 2913)
+++ src/org/openstreetmap/josm/gui/dialogs/changeset/SingleChangesetDownloadPanel.java	(Arbeitskopie)
@@ -29,7 +29,7 @@
  */
 public class SingleChangesetDownloadPanel extends JPanel {
 
-    private JTextField tfChangsetId;
+    private JTextField tfChangesetId;
     private DownloadAction actDownload;
     private ChangesetIdValidator valChangesetId;
 
@@ -43,15 +43,15 @@
         );
 
         add(new JLabel(tr("Changeset ID: ")));
-        add(tfChangsetId = new JTextField(10));
-        tfChangsetId.setToolTipText(tr("Enter a changset id"));
-        valChangesetId  =ChangesetIdValidator.decorate(tfChangsetId);
-        SelectAllOnFocusGainedDecorator.decorate(tfChangsetId);
+        add(tfChangesetId = new JTextField(10));
+        tfChangesetId.setToolTipText(tr("Enter a changeset id"));
+        valChangesetId  =ChangesetIdValidator.decorate(tfChangesetId);
+        SelectAllOnFocusGainedDecorator.decorate(tfChangesetId);
 
         actDownload = new DownloadAction();
         SideButton btn = new SideButton(actDownload);
-        tfChangsetId.addActionListener(actDownload);
-        tfChangsetId.getDocument().addDocumentListener(actDownload);
+        tfChangesetId.addActionListener(actDownload);
+        tfChangesetId.getDocument().addDocumentListener(actDownload);
         add(btn);
     }
 
@@ -65,7 +65,7 @@
      *
      * @return the changeset id entered in this panel
      */
-    public int getChangsetId() {
+    public int getChangesetId() {
         return valChangesetId.getChangesetId();
     }
 
@@ -83,7 +83,7 @@
         public void actionPerformed(ActionEvent arg0) {
             if (!isEnabled())
                 return;
-            int id = getChangsetId();
+            int id = getChangesetId();
             if (id == 0) return;
             ChangesetContentDownloadTask task =  new ChangesetContentDownloadTask(
                     SingleChangesetDownloadPanel.this,
@@ -93,7 +93,7 @@
         }
 
         protected void updateEnabledState() {
-            String v = tfChangsetId.getText();
+            String v = tfChangesetId.getText();
             if (v == null || v.trim().length() == 0) {
                 setEnabled(false);
                 return;
Index: src/org/openstreetmap/josm/gui/dialogs/changeset/query/BasicChangesetQueryPanel.java
===================================================================
--- src/org/openstreetmap/josm/gui/dialogs/changeset/query/BasicChangesetQueryPanel.java	(Revision 2913)
+++ src/org/openstreetmap/josm/gui/dialogs/changeset/query/BasicChangesetQueryPanel.java	(Arbeitskopie)
@@ -106,7 +106,7 @@
         gc.fill = GridBagConstraints.HORIZONTAL;
         gc.weightx = 1.0;
         pnl.add(cbMyChangesetsOnly = new JCheckBox(tr("Download my changesets only")), gc);
-        cbMyChangesetsOnly.setToolTipText(tr("<html>Select to restrict the query to your changsets only.<br>Unselect to include all changesets in the query.</html>"));
+        cbMyChangesetsOnly.setToolTipText(tr("<html>Select to restrict the query to your changesets only.<br>Unselect to include all changesets in the query.</html>"));
 
         // grab remaining space
         gc.gridx = 0;
Index: src/org/openstreetmap/josm/gui/dialogs/changeset/query/ChangesetQueryTask.java
===================================================================
--- src/org/openstreetmap/josm/gui/dialogs/changeset/query/ChangesetQueryTask.java	(Revision 2913)
+++ src/org/openstreetmap/josm/gui/dialogs/changeset/query/ChangesetQueryTask.java	(Arbeitskopie)
@@ -37,7 +37,7 @@
     private ChangesetQuery query;
     /** true if the task was canceled */
     private boolean canceled;
-    /** the set of downloaded changsets */
+    /** the set of downloaded changesets */
     private Set<Changeset> downloadedChangesets;
     /** the last exception remembered, if any */
     private Exception lastException;
Index: src/org/openstreetmap/josm/gui/dialogs/ChangesetDialog.java
===================================================================
--- src/org/openstreetmap/josm/gui/dialogs/ChangesetDialog.java	(Revision 2913)
+++ src/org/openstreetmap/josm/gui/dialogs/ChangesetDialog.java	(Arbeitskopie)
@@ -80,7 +80,7 @@
     // the actions
     private SelectObjectsAction selectObjectsAction;
     private  ReadChangesetsAction readChangesetAction;
-    private ShowChangesetInfoAction showChangsetInfoAction;
+    private ShowChangesetInfoAction showChangesetInfoAction;
     private CloseOpenChangesetsAction closeChangesetAction;
     private LaunchChangesetManagerAction launchChangesetManagerAction;
 
@@ -201,11 +201,11 @@
         lstInSelection.getSelectionModel().addListSelectionListener(closeChangesetAction);
 
         // -- show info action
-        showChangsetInfoAction = new ShowChangesetInfoAction();
-        tp.add(new SideButton(showChangsetInfoAction, false));
-        cbInSelectionOnly.addItemListener(showChangsetInfoAction);
-        lstInActiveDataLayer.getSelectionModel().addListSelectionListener(showChangsetInfoAction);
-        lstInSelection.getSelectionModel().addListSelectionListener(showChangsetInfoAction);
+        showChangesetInfoAction = new ShowChangesetInfoAction();
+        tp.add(new SideButton(showChangesetInfoAction, false));
+        cbInSelectionOnly.addItemListener(showChangesetInfoAction);
+        lstInActiveDataLayer.getSelectionModel().addListSelectionListener(showChangesetInfoAction);
+        lstInSelection.getSelectionModel().addListSelectionListener(showChangesetInfoAction);
 
         // -- launch changeset manager action
         launchChangesetManagerAction = new LaunchChangesetManagerAction();
@@ -573,7 +573,7 @@
             add(readChangesetAction);
             add(closeChangesetAction);
             addSeparator();
-            add(showChangsetInfoAction);
+            add(showChangesetInfoAction);
         }
     }
 }
Index: src/org/openstreetmap/josm/gui/dialogs/relation/GenericRelationEditor.java
===================================================================
--- src/org/openstreetmap/josm/gui/dialogs/relation/GenericRelationEditor.java	(Revision 2913)
+++ src/org/openstreetmap/josm/gui/dialogs/relation/GenericRelationEditor.java	(Arbeitskopie)
@@ -1079,7 +1079,7 @@
                     new ButtonSpec(
                             tr("No, continue editing"),
                             ImageProvider.get("cancel"),
-                            tr("Click to to return to the relation editor and to resume relation editing") ,
+                            tr("Click to return to the relation editor and to resume relation editing") ,
                             null /* no specific help topic */
                     )
             };
Index: src/org/openstreetmap/josm/gui/help/HelpBrowser.java
===================================================================
--- src/org/openstreetmap/josm/gui/help/HelpBrowser.java	(Revision 2913)
+++ src/org/openstreetmap/josm/gui/help/HelpBrowser.java	(Arbeitskopie)
@@ -225,7 +225,7 @@
         String message = tr("<html><p class=\"warning-header\">Help content for help topic missing</p>"
                 + "<p class=\"warning-body\">Help content for the help topic <strong>{0}</strong> is "
                 + "not available yet. It is missing both in your local language ({1}) and in english.<br><br>"
-                + "Please help to improve the JOSM help system and fill in the missing information."
+                + "Please help to improve the JOSM help system and fill in the missing information. "
                 + "You can both edit the <a href=\"{2}\">help topic in your local language ({1})</a> and "
                 + "the <a href=\"{3}\">help topic in english</a>."
                 + "</p></html>",
@@ -347,7 +347,7 @@
                         Main.parent,
                         tr(
                                 "<html>Failed to open help page for url {0}.<br>"
-                                + "This is most likely due to a network problem, please check your<br>"
+                                + "This is most likely due to a network problem, please check<br>"
                                 + "your internet connection</html>",
                                 url.toString()
                         ),
Index: src/org/openstreetmap/josm/gui/io/DownloadOpenChangesetsTask.java
===================================================================
--- src/org/openstreetmap/josm/gui/io/DownloadOpenChangesetsTask.java	(Revision 2913)
+++ src/org/openstreetmap/josm/gui/io/DownloadOpenChangesetsTask.java	(Arbeitskopie)
@@ -118,7 +118,7 @@
             if (im.isFullyIdentified()) {
                 im.setPartiallyIdentified(im.getUserName());
             }
-            System.err.println(tr("Warning: Failed to retrieve user infos for the current JOSM user. Exceptions was: {0}", e.toString()));
+            System.err.println(tr("Warning: Failed to retrieve user infos for the current JOSM user. Exception was: {0}", e.toString()));
         }
     }
 
Index: src/org/openstreetmap/josm/gui/io/UploadParameterSummaryPanel.java
===================================================================
--- src/org/openstreetmap/josm/gui/io/UploadParameterSummaryPanel.java	(Revision 2913)
+++ src/org/openstreetmap/josm/gui/io/UploadParameterSummaryPanel.java	(Arbeitskopie)
@@ -38,7 +38,7 @@
     private boolean closeChangesetAfterNextUpload;
     private ConfigurationParameterRequestHandler configHandler;
 
-    protected String buildChangsetSummary() {
+    protected String buildChangesetSummary() {
         StringBuffer msg = new StringBuffer();
         if (selectedChangeset == null || selectedChangeset.isNew()) {
             msg.append(tr("Objects are uploaded to a <strong>new changeset</strong>."));
@@ -66,7 +66,7 @@
         // multiple changesets
         //
         boolean useOneChangeset = true;
-        int maxChunkSize = OsmApi.getOsmApi().getCapabilities().getMaxChangsetSize();
+        int maxChunkSize = OsmApi.getOsmApi().getCapabilities().getMaxChangesetSize();
         if (maxChunkSize > 0 && numObjects > maxChunkSize) {
             useOneChangeset = false;
         }
@@ -173,7 +173,7 @@
         sb.append("<html>");
         sb.append(buildStrategySummary());
         sb.append("<br><br>");
-        sb.append(buildChangsetSummary());
+        sb.append(buildChangesetSummary());
         sb.append("</html>");
         jepMessage.setText(sb.toString());
     }
Index: src/org/openstreetmap/josm/gui/io/UploadPrimitivesTask.java
===================================================================
--- src/org/openstreetmap/josm/gui/io/UploadPrimitivesTask.java	(Revision 2913)
+++ src/org/openstreetmap/josm/gui/io/UploadPrimitivesTask.java	(Arbeitskopie)
@@ -96,10 +96,10 @@
                 )
         };
         int numObjectsToUploadLeft = toUpload.getSize() - processedPrimitives.size();
-        String msg1 = tr("The server reported that the current changset was closed.<br>"
+        String msg1 = tr("The server reported that the current changeset was closed.<br>"
                 + "This is most likely because the changesets size exceeded the max. size<br>"
                 + "of {0} objects on the server ''{1}''.",
-                OsmApi.getOsmApi().getCapabilities().getMaxChangsetSize(),
+                OsmApi.getOsmApi().getCapabilities().getMaxChangesetSize(),
                 OsmApi.getOsmApi().getBaseUrl()
         );
         String msg2 = trn(
@@ -109,7 +109,7 @@
                 numObjectsToUploadLeft
         );
         String msg3 = tr(
-                "Click ''<strong>{0}</strong>'' to continue uploading to additional new changsets.<br>"
+                "Click ''<strong>{0}</strong>'' to continue uploading to additional new changesets.<br>"
                 + "Click ''<strong>{1}</strong>'' to return to the upload dialog.<br>"
                 + "Click ''<strong>{2}</strong>'' to abort uploading and return to map editing.<br>",
                 specs[0].text,
@@ -125,7 +125,7 @@
                 null, /* no special icon */
                 specs,
                 specs[0],
-                ht("/Action/UploadAction#ChangsetFull")
+                ht("/Action/UploadAction#ChangesetFull")
         );
         switch(ret) {
         case 0: return MaxChangesetSizeExceededPolicy.AUTOMATICALLY_OPEN_NEW_CHANGESETS;
@@ -137,7 +137,7 @@
         return null;
     }
 
-    protected void openNewChangset() {
+    protected void openNewChangeset() {
         // make sure the current changeset is removed from the upload dialog.
         //
         ChangesetCache.getInstance().update(changeset);
@@ -146,7 +146,7 @@
         this.changeset = newChangeSet;
     }
 
-    protected boolean recoverFromChangsetFullException() {
+    protected boolean recoverFromChangesetFullException() {
         if (toUpload.getSize() - processedPrimitives.size() == 0) {
             strategy.setPolicy(MaxChangesetSizeExceededPolicy.ABORT);
             return false;
@@ -167,7 +167,7 @@
         case AUTOMATICALLY_OPEN_NEW_CHANGESETS:
             // prepare the state of the task for a next iteration in uploading.
             //
-            openNewChangset();
+            openNewChangeset();
             toUpload.removeProcessed(processedPrimitives);
             return true;
         }
@@ -263,9 +263,9 @@
                     case UPLOAD_DATA:
                         // Most likely the changeset is full. Try to recover and continue
                         // with a new changeset, but let the user decide first (see
-                        // recoverFromChangsetFullException)
+                        // recoverFromChangesetFullException)
                         //
-                        if (recoverFromChangsetFullException()) {
+                        if (recoverFromChangesetFullException()) {
                             continue;
                         }
                         lastException = e;
Index: src/org/openstreetmap/josm/gui/io/CredentialDialog.java
===================================================================
--- src/org/openstreetmap/josm/gui/io/CredentialDialog.java	(Revision 2913)
+++ src/org/openstreetmap/josm/gui/io/CredentialDialog.java	(Arbeitskopie)
@@ -235,7 +235,7 @@
         protected void build() {
             super.build();
             tfUserName.setToolTipText(tr("Please enter the user name of your OSM account"));
-            tfPassword.setToolTipText(tr("Please enter the password name of your OSM account"));
+            tfPassword.setToolTipText(tr("Please enter the password of your OSM account"));
             lblHeading.setText(
                     "<html>" + tr("Authenticating at the OSM API ''{0}'' failed. Please enter a valid username and a valid password.",
                             OsmApi.getOsmApi().getBaseUrl()) + "</html>");
Index: src/org/openstreetmap/josm/gui/io/AbstractUploadTask.java
===================================================================
--- src/org/openstreetmap/josm/gui/io/AbstractUploadTask.java	(Revision 2913)
+++ src/org/openstreetmap/josm/gui/io/AbstractUploadTask.java	(Arbeitskopie)
@@ -190,11 +190,11 @@
      * know what {@see OsmPrimitive} actually caused the conflict (for whatever reason)
      *
      */
-    protected void handleUploadConflictForClosedChangeset(long changsetId, Date d) {
+    protected void handleUploadConflictForClosedChangeset(long changesetId, Date d) {
         String msg =  tr("<html>Uploading <strong>failed</strong> because you have been using<br>"
                 + "changeset {0} which was already closed at {1}.<br>"
                 + "Please upload again with a new or an existing open changeset.</html>",
-                changsetId, new SimpleDateFormat().format(d)
+                changesetId, new SimpleDateFormat().format(d)
         );
         JOptionPane.showMessageDialog(
                 Main.parent,
Index: src/org/openstreetmap/josm/gui/io/UploadStrategySelectionPanel.java
===================================================================
--- src/org/openstreetmap/josm/gui/io/UploadStrategySelectionPanel.java	(Revision 2913)
+++ src/org/openstreetmap/josm/gui/io/UploadStrategySelectionPanel.java	(Arbeitskopie)
@@ -220,7 +220,7 @@
         gc.weighty = 1.0;
         add(new JPanel(), gc);
 
-        int maxChunkSize = OsmApi.getOsmApi().getCapabilities().getMaxChangsetSize();
+        int maxChunkSize = OsmApi.getOsmApi().getCapabilities().getMaxChangesetSize();
         pnlMultiChangesetPolicyPanel.setVisible(
                 maxChunkSize > 0 && numUploadedObjects > maxChunkSize
         );
@@ -315,7 +315,7 @@
     }
 
     protected void updateNumRequestsLabels() {
-        int maxChunkSize = OsmApi.getOsmApi().getCapabilities().getMaxChangsetSize();
+        int maxChunkSize = OsmApi.getOsmApi().getCapabilities().getMaxChangesetSize();
         if (maxChunkSize > 0 && numUploadedObjects > maxChunkSize) {
             rbStrategy.get(UploadStrategy.SINGLE_REQUEST_STRATEGY).setEnabled(false);
             JLabel lbl = lblStrategies.get(UploadStrategy.SINGLE_REQUEST_STRATEGY);
@@ -406,7 +406,7 @@
         protected void valiateChunkSize() {
             try {
                 int chunkSize = Integer.parseInt(tfChunkSize.getText().trim());
-                int maxChunkSize = OsmApi.getOsmApi().getCapabilities().getMaxChangsetSize();
+                int maxChunkSize = OsmApi.getOsmApi().getCapabilities().getMaxChangesetSize();
                 if (chunkSize <= 0) {
                     setErrorFeedback(tfChunkSize, tr("Illegal chunk size <= 0. Please enter an integer > 1"));
                 } else if (maxChunkSize > 0 && chunkSize > maxChunkSize) {
Index: src/org/openstreetmap/josm/io/Capabilities.java
===================================================================
--- src/org/openstreetmap/josm/io/Capabilities.java	(Revision 2913)
+++ src/org/openstreetmap/josm/io/Capabilities.java	(Arbeitskopie)
@@ -79,7 +79,7 @@
      *
      * @return the max number of objects in a changeset
      */
-    public int getMaxChangsetSize() {
+    public int getMaxChangesetSize() {
         String v = get("changesets", "maximum_elements");
         if (v == null) return -1;
         try {
Index: src/org/openstreetmap/josm/io/OsmServerChangesetReader.java
===================================================================
--- src/org/openstreetmap/josm/io/OsmServerChangesetReader.java	(Revision 2913)
+++ src/org/openstreetmap/josm/io/OsmServerChangesetReader.java	(Arbeitskopie)
@@ -163,9 +163,9 @@
     /**
      * Downloads the content of a changeset
      *
-     * @param id the changset id. >0 required.
+     * @param id the changeset id. >0 required.
      * @param monitor the progress monitor. {@see NullProgressMonitor#INSTANCE} assumed if null.
-     * @return the changset content
+     * @return the changeset content
      * @throws IllegalArgumentException thrown if id <= 0
      * @throws OsmTransferException thrown if something went wrong
      */
Index: src/org/openstreetmap/josm/io/MultiFetchServerObjectReader.java
===================================================================
--- src/org/openstreetmap/josm/io/MultiFetchServerObjectReader.java	(Revision 2913)
+++ src/org/openstreetmap/josm/io/MultiFetchServerObjectReader.java	(Arbeitskopie)
@@ -155,7 +155,7 @@
     }
 
     /**
-     * appends a {@see Way}s id and the list of ids of nodes the way refers to to the list of ids which will be fetched from the server.
+     * appends a {@see Way}s id and the list of ids of nodes the way refers to the list of ids which will be fetched from the server.
      *
      * @param way the way (ignored, if null)
      * @return this
Index: src/org/openstreetmap/josm/data/APIDataSet.java
===================================================================
--- src/org/openstreetmap/josm/data/APIDataSet.java	(Revision 2913)
+++ src/org/openstreetmap/josm/data/APIDataSet.java	(Arbeitskopie)
@@ -276,7 +276,7 @@
     }
 
     /**
-     * Utility class to sort a collection of of new relations with their dependencies
+     * Utility class to sort a collection of new relations with their dependencies
      * topologically.
      *
      */
Index: src/org/openstreetmap/josm/data/conflict/ConflictCollection.java
===================================================================
--- src/org/openstreetmap/josm/data/conflict/ConflictCollection.java	(Revision 2913)
+++ src/org/openstreetmap/josm/data/conflict/ConflictCollection.java	(Arbeitskopie)
@@ -82,7 +82,7 @@
     /**
      * Adds a conflict to the collection of conflicts.
      *
-     * @param conflict the conflict to to add. Must not be null.
+     * @param conflict the conflict to add. Must not be null.
      * @throws IllegalArgumentException thrown, if conflict is null
      * @throws IllegalStateException thrown if this collection already includes a conflict for conflict.getMy()
      *

Index: src/org/openstreetmap/josm/gui/dialogs/changeset/ChangesetContentDownloadTask.java
===================================================================
--- src/org/openstreetmap/josm/gui/dialogs/changeset/ChangesetContentDownloadTask.java	(Revision 2913)
+++ src/org/openstreetmap/josm/gui/dialogs/changeset/ChangesetContentDownloadTask.java	(Arbeitskopie)
@@ -115,12 +115,12 @@
      * Replies true if the local {@see ChangesetCache} already includes the changeset with
      * id <code>changesetId</code>.
      *
      * @param changsetId the changeset id
      * @return true if the local {@see ChangesetCache} already includes the changeset with
      * id <code>changesetId</code>
      */
-    protected boolean isAvailableLocally(int changsetId) {
-        return ChangesetCache.getInstance().get(changsetId) != null;
+    protected boolean isAvailableLocally(int changesetId) {
+        return ChangesetCache.getInstance().get(changesetId) != null;
     }
 
     /**
@@ -115,12 +115,12 @@
      * id <code>changesetId</code>.
      *
-     * @param changsetId the changeset id
+     * @param changesetId the changeset id
      * @return true if the local {@see ChangesetCache} already includes the changeset with
      * id <code>changesetId</code>